@@ -34,14 +34,14 @@ protected:
   //overrides:
   virtual void on_start_document();
   virtual void on_end_document();
-  virtual void on_start_element(const std::string& name,
+  virtual void on_start_element(const Glib::ustring& name,
                                 const AttributeList& properties);
-  virtual void on_end_element(const std::string& name);
-  virtual void on_characters(const std::string& characters);
-  virtual void on_comment(const std::string& text);
-  virtual void on_warning(const std::string& text);
-  virtual void on_error(const std::string& text);
-  virtual void on_fatal_error(const std::string& text);
+  virtual void on_end_element(const Glib::ustring& name);
+  virtual void on_characters(const Glib::ustring& characters);
+  virtual void on_comment(const Glib::ustring& text);
+  virtual void on_warning(const Glib::ustring& text);
+  virtual void on_error(const Glib::ustring& text);
+  virtual void on_fatal_error(const Glib::ustring& text);
 };
 
 
